… | OiRA

Help

1. Preparação
2. Envolvimento
3. Identificação + Avaliação
   1. 1 Commercial manned guarding
   2. Ω Riscos adicionados (por si)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Sem resposta
   - Adiado
   - OK
   - Atenção
4. Plano de Ação
5. Relatório
6. Estado 0%

## Descreva o risco…

O risco é aceitável? Não, são necessárias mais medidas Sim, o risco remanescente é aceitável

Select the priority of this risk Low Medium High
Informação
Adicione imagemlabel_upload_image
Comentários

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More